@@ -8,14 +8,14 @@ from collections import UserDict
 from typing import Any, Dict, List, Optional, Tuple, TypeVar, Union
 
 from ckanapi.errors import NotFound
+
+from hdx.hdx_configuration import Configuration
 from hdx.utilities.dictandlist import merge_two_dictionaries
 from hdx.utilities.loader import (
     load_json_into_existing_dict,
     load_yaml_into_existing_dict,
 )
 
-from hdx.hdx_configuration import Configuration
-
 logger = logging.getLogger(__name__)
 
 HDXObjectUpperBound = TypeVar("HDXObjectUpperBound", bound="HDXObject")
@@ -118,7 +118,9 @@ class HDXObject(UserDict):
         except NotFound:
             return False, f"{fieldname}={value}: not found!"
         except Exception as e:
-            raise HDXError(f"Failed when trying to read: {fieldname}={value}! (POST)") from e
+            raise HDXError(
+                f"Failed when trying to read: {fieldname}={value}! (POST)"
+            ) from e
 
     def _load_from_hdx(self, object_type: str, id_field: str) -> bool:
         """Helper method to load the HDX object given by identifier from HDX
